.. include:: ../../../metalsmith_ansible/roles/metalsmith_deployment/README.rst

Module - metalsmith_instances
=============================

.. ansibleautoplugin::
   :module: metalsmith_ansible/ansible_plugins/modules/metalsmith_instances.py
   :documentation: true
   :examples: true
